# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: paperpilot_common/protobuf/monitor/server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n/paperpilot_common/protobuf/monitor/server.proto\x12\x07monitor\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto"v\n\x0cServerStatus\x12\x12\n\nhost_count\x18\x01 \x01(\x05\x12(\n\x08projects\x18\x02 \x03(\x0b\x32\x16.monitor.ProjectStatus\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"j\n\rProjectStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rhealthy_count\x18\x04 \x01(\x05\x12\x13\n\x0btotal_count\x18\x05 \x01(\x05\x32R\n\x14MonitorPublicService\x12:\n\tGetStatus\x12\x16.google.protobuf.Empty\x1a\x15.monitor.ServerStatusb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "paperpilot_common.protobuf.monitor.server_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SERVERSTATUS"]._serialized_start = 122
    _globals["_SERVERSTATUS"]._serialized_end = 240
    _globals["_PROJECTSTATUS"]._serialized_start = 242
    _globals["_PROJECTSTATUS"]._serialized_end = 348
    _globals["_MONITORPUBLICSERVICE"]._serialized_start = 350
    _globals["_MONITORPUBLICSERVICE"]._serialized_end = 432
# @@protoc_insertion_point(module_scope)
