"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TranslationRequest(google.protobuf.message.Message):
    """翻译请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    SOURCE_LANGUAGE_FIELD_NUMBER: builtins.int
    TARGET_LANGUAGE_FIELD_NUMBER: builtins.int
    content: builtins.str
    """翻译内容"""
    source_language: builtins.str
    """源语言"""
    target_language: builtins.str
    """目标语言"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        source_language: builtins.str | None = ...,
        target_language: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_source_language",
            b"_source_language",
            "_target_language",
            b"_target_language",
            "source_language",
            b"source_language",
            "target_language",
            b"target_language",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_source_language",
            b"_source_language",
            "_target_language",
            b"_target_language",
            "content",
            b"content",
            "source_language",
            b"source_language",
            "target_language",
            b"target_language",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_source_language", b"_source_language"]
    ) -> typing_extensions.Literal["source_language"] | None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_language", b"_target_language"]
    ) -> typing_extensions.Literal["target_language"] | None: ...

global___TranslationRequest = TranslationRequest

@typing_extensions.final
class TranslationResponse(google.protobuf.message.Message):
    """翻译响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    result: builtins.str
    """翻译结果"""
    def __init__(
        self,
        *,
        result: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___TranslationResponse = TranslationResponse
