# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: paperpilot_common/protobuf/translation/translation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n8paperpilot_common/protobuf/translation/translation.proto\x12\x0btranslation"\x89\x01\n\x12TranslationRequest\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x1c\n\x0fsource_language\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0ftarget_language\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x12\n\x10_source_languageB\x12\n\x10_target_language"%\n\x13TranslationResponse\x12\x0e\n\x06result\x18\x01 \x01(\t2j\n\x18TranslationPublicService\x12N\n\ttranslate\x12\x1f.translation.TranslationRequest\x1a .translation.TranslationResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "paperpilot_common.protobuf.translation.translation_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TRANSLATIONREQUEST"]._serialized_start = 74
    _globals["_TRANSLATIONREQUEST"]._serialized_end = 211
    _globals["_TRANSLATIONRESPONSE"]._serialized_start = 213
    _globals["_TRANSLATIONRESPONSE"]._serialized_end = 250
    _globals["_TRANSLATIONPUBLICSERVICE"]._serialized_start = 252
    _globals["_TRANSLATIONPUBLICSERVICE"]._serialized_end = 358
# @@protoc_insertion_point(module_scope)
