# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: paperpilot_common/protobuf/monitor/client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n/paperpilot_common/protobuf/monitor/client.proto\x12\x07monitor\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto"v\n\x0c\x43lientStatus\x12\x0c\n\x04host\x18\x01 \x01(\t\x12.\n\x08projects\x18\x02 \x03(\x0b\x32\x1c.monitor.ClientProjectStatus\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"_\n\x13\x43lientProjectStatus\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x32\n\ncontainers\x18\x02 \x03(\x0b\x32\x1e.monitor.ClientContainerStatus"`\n\x15\x43lientContainerStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x1f\n\x06status\x18\x04 \x01(\x0e\x32\x0f.monitor.Status*Y\n\x06Status\x12\x0b\n\x07RUNNING\x10\x00\x12\x0b\n\x07STOPPED\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\x0b\n\x07HEALTHY\x10\x03\x12\r\n\tUNHEALTHY\x10\x04\x12\x0b\n\x07UNKNOWN\x10\x05\x32R\n\x14MonitorClientService\x12:\n\tGetStatus\x12\x16.google.protobuf.Empty\x1a\x15.monitor.ClientStatusb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "paperpilot_common.protobuf.monitor.client_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STATUS"]._serialized_start = 437
    _globals["_STATUS"]._serialized_end = 526
    _globals["_CLIENTSTATUS"]._serialized_start = 122
    _globals["_CLIENTSTATUS"]._serialized_end = 240
    _globals["_CLIENTPROJECTSTATUS"]._serialized_start = 242
    _globals["_CLIENTPROJECTSTATUS"]._serialized_end = 337
    _globals["_CLIENTCONTAINERSTATUS"]._serialized_start = 339
    _globals["_CLIENTCONTAINERSTATUS"]._serialized_end = 435
    _globals["_MONITORCLIENTSERVICE"]._serialized_start = 528
    _globals["_MONITORCLIENTSERVICE"]._serialized_end = 610
# @@protoc_insertion_point(module_scope)
