# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: paperpilot_common/protobuf/ai/ai.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&paperpilot_common/protobuf/ai/ai.proto\x12\x02\x61i"\\\n\tGptResult\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12,\n\rfinish_reason\x18\x02 \x01(\x0e\x32\x10.ai.FinishReasonH\x00\x88\x01\x01\x42\x10\n\x0e_finish_reason"*\n\nGptRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t*U\n\x0c\x46inishReason\x12\x08\n\x04NULL\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\n\n\x06LENGTH\x10\x02\x12\x11\n\rFUNCTION_CALL\x10\x03\x12\x12\n\x0e\x43ONTENT_FILTER\x10\x04\x32\x34\n\nGptService\x12&\n\x03\x41sk\x12\x0e.ai.GptRequest\x1a\r.ai.GptResult0\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "paperpilot_common.protobuf.ai.ai_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_FINISHREASON"]._serialized_start = 184
    _globals["_FINISHREASON"]._serialized_end = 269
    _globals["_GPTRESULT"]._serialized_start = 46
    _globals["_GPTRESULT"]._serialized_end = 138
    _globals["_GPTREQUEST"]._serialized_start = 140
    _globals["_GPTREQUEST"]._serialized_end = 182
    _globals["_GPTSERVICE"]._serialized_start = 271
    _globals["_GPTSERVICE"]._serialized_end = 323
# @@protoc_insertion_point(module_scope)
